@@ -1,4 +1,3 @@
-from idecomp._utils.registrodecomp import RegistroDecomp
 from idecomp.decomp.modelos.dadger import LeituraDadger
 from idecomp.decomp.modelos.dadger import TE, SB, UH, CT, UE, DP, CD, PQ  # noqa
 from idecomp.decomp.modelos.dadger import RI, IA, TX, GP, NI, DT, MP, MT  # noqa
@@ -442,6 +441,22 @@ class Dadger(ArquivoRegistros):
         raise ValueError("Não foi encontrado registro TI" +
                          f" para a UHE {codigo}")
 
+    def rq(self, ree: int) -> RQ:
+        """
+        Obtém um registro que especifica as vazões mínimas históricas
+        por REE existentes no estudo especificado no :class:`Dadger`
+
+        :param ree: Código do REE
+        :type ree: int
+        :return: Um registro do tipo :class:`RQ`
+        """
+        regs: List[RQ] = self.__obtem_registros(RQ)
+        for r in regs:
+            if r.ree == ree:
+                return r
+        raise ValueError("Não foi encontrado registro RQ" +
+                         f" para o REE {ree}")
+
     def ve(self, codigo: int) -> VE:
         """
         Obtém um registro que especifica os volumes de espera
@@ -698,10 +713,3 @@ class Dadger(ArquivoRegistros):
         """
         r = self.__obtem_registro(FJ)
         return r
-
-    def deleta_registro(self, reg: RegistroDecomp) -> bool:
-        try:
-            self._dados.registros.remove(reg)
-            return True
-        except ValueError:
-            return False
